@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   03 mai 2016
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -11,16 +11,23 @@
  * project under specific licensing conditions.
  */
 
-#include <boost/python.hpp>
+#include <pybind11/pybind11.h>
+#include <pybind11/stl.h>
 #include "MFront/DSLFactory.hxx"
 
-void declareDSLFactory() {
-  using namespace boost::python;
+static auto createNewDSL(mfront::DSLFactory& f, const std::string& n) {
+  return f.createNewDSL(n, {});
+}
+
+void declareDSLFactory(pybind11::module_&);
+
+void declareDSLFactory(pybind11::module_& m) {
   using namespace mfront;
-  class_<DSLFactory, boost::noncopyable>("DSLFactory", no_init)
-      .def("getDSLFactory", DSLFactory::getDSLFactory,
-           return_value_policy<reference_existing_object>())
-      .staticmethod("getDSLFactory")
+  pybind11::class_<DSLFactory>(m, "DSLFactory")
+      .def_static("getDSLFactory", DSLFactory::getDSLFactory,
+                  pybind11::return_value_policy::reference)
+      .def("createNewParser", &createNewDSL)
+      .def("createNewDSL", &createNewDSL)
       .def("createNewParser", &DSLFactory::createNewDSL)
       .def("createNewDSL", &DSLFactory::createNewDSL);
 }
