@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   04 mai 2016
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -11,13 +11,15 @@
  * project under specific licensing conditions.
  */
 
-#include <boost/python.hpp>
+#include <pybind11/pybind11.h>
+#include <pybind11/stl.h>
 #include "MFront/FileDescription.hxx"
 
-void declareFileDescription() {
-  using namespace boost::python;
+void declareFileDescription(pybind11::module_&);
+
+void declareFileDescription(pybind11::module_& m) {
   using namespace mfront;
-  class_<mfront::FileDescription>("FileDescription")
+  pybind11::class_<mfront::FileDescription>(m, "FileDescription")
       .def_readwrite("fileName", &mfront::FileDescription::fileName)
       .def_readwrite("authorName", &mfront::FileDescription::authorName)
       .def_readwrite("date", &mfront::FileDescription::date)
