@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \brief 20 sept. 2013
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -11,17 +11,16 @@
  * project under specific licensing conditions.
  */
 
-#include <boost/python.hpp>
-
+#include <pybind11/pybind11.h>
+#include <pybind11/stl.h>
 #include "TFEL/Tests/TestResult.hxx"
 
-void declareTestResult();
+void declareTestResult(pybind11::module_&);
 
-void declareTestResult() {
-  using namespace boost;
-  using namespace boost::python;
+void declareTestResult(pybind11::module_& m) {
   using namespace tfel::tests;
-  class_<TestResult>("TestResult")
+  pybind11::class_<TestResult>(m, "TestResult")
+      .def(pybind11::init<>())
       .def("success", &TestResult::success)
       .def("duration", &TestResult::duration);
 
