@@ -12,6 +12,7 @@
 #include "TFEL/Glossary/GlossaryEntry.hxx"
 #include "TFEL/Utilities/StringAlgorithms.hxx"
 #include "TFEL/Material/ModellingHypothesis.hxx"
+#include "MFront/BehaviourDSLUtilities.hxx"
 #include "MFront/BehaviourBrick/IsotropicHardeningRule.hxx"
 #include "MFront/BehaviourBrick/BrickUtilities.hxx"
 
@@ -54,37 +55,6 @@ namespace mfront::bbrick {
     return c;
   }  // end of generateMaterialPropertyInitializationCode
 
-  BehaviourDescription::MaterialProperty
-  getBehaviourDescriptionMaterialProperty(AbstractBehaviourDSL& dsl,
-                                          const std::string_view n,
-                                          const tfel::utilities::Data& d) {
-    if (d.is<double>()) {
-      BehaviourDescription::ConstantMaterialProperty cmp;
-      cmp.value = d.get<double>();
-      return cmp;
-    } else if (d.is<int>()) {
-      BehaviourDescription::ConstantMaterialProperty cmp;
-      cmp.value = static_cast<double>(d.get<int>());
-      return cmp;
-    }
-    if (!d.is<std::string>()) {
-      tfel::raise(
-          "getBehaviourDescriptionMaterialProperty: "
-          "unsupported data type for material property '" +
-          std::string(n) + "'");
-    }
-    const auto mp = d.get<std::string>();
-    if (tfel::utilities::ends_with(mp, ".mfront")) {
-      // file name
-      BehaviourDescription::ExternalMFrontMaterialProperty emp;
-      emp.mpd = dsl.handleMaterialPropertyDescription(mp);
-      return emp;
-    }
-    BehaviourDescription::AnalyticMaterialProperty amp;
-    amp.f = mp;
-    return amp;
-  }  // end of getBehaviourDescriptionMaterialProperty_impl
-
   void declareParameterOrLocalVariable(
       BehaviourDescription& bd,
       BehaviourDescription::MaterialProperty& mp,
@@ -561,7 +531,7 @@ namespace mfront::bbrick {
       const auto id = std::to_string(i);
       c += ihrs[i]->computeElasticLimitAndDerivative(bd, fid, id);
       const auto Ri = "R" + fid + "_" + id;
-      const auto dRi = "d" + Ri + "_ddp" + fid;
+      const auto dRi = "d" + Ri + "_dp" + fid;
       R += Ri;
       dR += dRi;
       if (++i != ihrs.size()) {
@@ -570,7 +540,7 @@ namespace mfront::bbrick {
       }
     }
     c += "const auto R" + fid + " = " + R + ";\n";
-    c += "const auto dR" + fid + "_ddp" + fid + " = " + dR + ";\n";
+    c += "const auto dR" + fid + "_dp" + fid + " = " + dR + ";\n";
     return c;
   }  // end of computeElasticLimitAndDerivative
 
