@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   17 Jan 2007
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -21,13 +21,15 @@
 #include "TFEL/Utilities/StringAlgorithms.hxx"
 #include "TFEL/System/System.hxx"
 
-#include "MFront/DSLUtilities.hxx"
+#include "MFront/MFrontWarningMode.hxx"
 #include "MFront/MFrontLock.hxx"
 #include "MFront/MFrontUtilities.hxx"
+#include "MFront/CodeGeneratorUtilities.hxx"
 #include "MFront/MFrontLogStream.hxx"
 #include "MFront/MFrontDebugMode.hxx"
 #include "MFront/FileDescription.hxx"
 #include "MFront/TargetsDescription.hxx"
+#include "MFront/VariableDescription.hxx"
 #include "MFront/CalculiXSymbolsGenerator.hxx"
 #include "MFront/CalculiXInterface.hxx"
 
@@ -288,11 +290,23 @@ namespace mfront {
     auto throw_if = [](const bool b, const std::string& m) {
       tfel::raise_if(b, "CalculiXInterface::treatKeyword: " + m);
     };
+    auto check_interface_restriction = [&i, &k] {
+      if (i.empty()) {
+        reportWarning(
+            "keyword '" + k +
+            "' is used without being restricted "
+            "to the `generic` interface, which could be a portability "
+            "issue. Please add [generic] after the "
+            "keyword (i.e. replace '" +
+            k + "' by '" + k + "[generic]')");
+      }
+    };
     if (!i.empty()) {
       if (std::find(i.begin(), i.end(), this->getName()) != i.end()) {
         const auto keys =
             std::vector<std::string>{"@CalculiXFiniteStrainStrategy",
-                                     "@CalculiXGenerateMTestFileOnFailure"};
+                                     "@CalculiXGenerateMTestFileOnFailure",
+                                     "@GenerateMTestFileOnFailure"};
         throw_if(std::find(keys.begin(), keys.end(), k) == keys.end(),
                  "unsupported key '" + k + "'");
       } else {
@@ -300,6 +314,7 @@ namespace mfront {
       }
     }
     if (k == "@CalculiXFiniteStrainStrategy") {
+      check_interface_restriction();
       throw_if(bd.hasAttribute(CalculiXInterface::finiteStrainStrategy),
                "a finite strain strategy has already been defined");
       throw_if(current == end, "unexpected end of file");
@@ -311,7 +326,11 @@ namespace mfront {
       checkFiniteStrainStrategyDefinitionConsistency(bd, fs);
       bd.setAttribute(CalculiXInterface::finiteStrainStrategy, fs, false);
       return {true, current};
-    } else if (k == "@CalculiXGenerateMTestFileOnFailure") {
+    } else if ((k == "@CalculiXGenerateMTestFileOnFailure") ||
+               (k == "@GenerateMTestFileOnFailure")) {
+      if (k == "@CalculiXGenerateMTestFileOnFailure") {
+        check_interface_restriction();
+      }
       this->setGenerateMTestFileOnFailureAttribute(
           bd, this->readBooleanValue(k, current, end));
       return {true, current};
@@ -961,10 +980,6 @@ namespace mfront {
     const auto name = bd.getLibrary() + bd.getClassName();
     const auto tfel_config = tfel::getTFELConfigExecutableName();
     auto& l = d.getLibrary(lib);
-    insert_if(l.cppflags,
-              "$(shell " + tfel_config + " --cppflags --compiler-flags)");
-    insert_if(l.include_directories,
-              "$(shell " + tfel_config + " --include-path)");
     insert_if(l.sources, "calculix" + name + ".cxx");
     d.headers.push_back("MFront/CalculiX/calculix" + name + ".hxx");
     insert_if(l.link_directories,
@@ -1213,6 +1228,7 @@ namespace mfront {
   void CalculiXInterface::writeInputFileExample(const BehaviourDescription& mb,
                                                 const FileDescription& fd,
                                                 const bool b) const {
+    constexpr auto h = ModellingHypothesis::TRIDIMENSIONAL;
     try {
       auto throw_if = [](const bool c, const std::string& m) {
         tfel::raise_if(c, "CalculiXInterface::writeInputFileExample: " + m);
@@ -1222,6 +1238,69 @@ namespace mfront {
       const auto fn = (b ? "calculix/" : "calculix-explicit/") + name + ".inp";
       std::ofstream out{fn};
       throw_if(!out, "could not open file '" + fn + "'");
+      auto write_variables_names = [&out](const auto variables,
+                                          const bool add_comment_mark,
+                                          const char* const prefix = nullptr) {
+        if (!variables.empty()) {
+          int i = 1;
+          int current = 1;
+          auto write = [&i, &current, &out, &add_comment_mark, &prefix](
+                           const VariableDescription& v, const std::string& n) {
+            auto write_line_break_if_required = [&i, &out, &add_comment_mark] {
+              if (i % 9 == 0) {
+                out << "\n";
+                if (add_comment_mark) {
+                  out << "** ";
+                }
+                i = 1;
+              }
+            };
+            if (v.isScalar()) {
+              write_line_break_if_required();
+              out << '<';
+              if (prefix != nullptr) {
+                out << prefix << current << ": ";
+              }
+              out << n << '>';
+              ++i;
+              ++current;
+            } else {
+              const auto vs = SupportedTypes::getTypeSize(v.type, 1u)
+                                  .getValueForModellingHypothesis(h);
+              for (int idx = 0; idx != vs; ++i) {
+                write_line_break_if_required();
+                out << '<';
+                if (prefix != nullptr) {
+                  out << prefix << current << ": ";
+                }
+                out << n << '_' << idx << '>';
+                ++current;
+                if (++idx != vs) {
+                  out << ", ";
+                }
+              }
+            }
+          };
+          if (add_comment_mark) {
+            out << "** ";
+          }
+          for (auto pv = variables.begin(); pv != variables.end();) {
+            if (pv->arraySize == 1u) {
+              write(*pv, pv->getExternalName());
+            } else {
+              for (unsigned short a = 0; a != pv->arraySize;) {
+                write(*pv, pv->getExternalName() + "_" + std::to_string(a));
+                if (++a != pv->arraySize) {
+                  out << ", ";
+                }
+              }
+            }
+            if (++pv != variables.end()) {
+              out << ", ";
+            }
+          }
+        }
+      };
       // header
       out << "** \n"
           << "** File generated by MFront from the " << fd.fileName
@@ -1231,8 +1310,6 @@ namespace mfront {
           << "** Author " << fd.authorName << '\n'
           << "** Date   " << fd.date << '\n'
           << "**\n\n";
-      // loop over hypothesis
-      const auto h = ModellingHypothesis::TRIDIMENSIONAL;
       const auto& d = mb.getBehaviourData(h);
       const auto mps = this->buildMaterialPropertiesList(mb, h);
       auto msize = SupportedTypes::TypeSize{};
@@ -1261,6 +1338,20 @@ namespace mfront {
         out << "*DENSITY\n<density>\n";
       }
       if (vsize != 0) {
+        out << "** list of internal state variables:\n";
+        auto isvs = persistentVarsHolder;
+        if ((mb.getBehaviourType() ==
+             BehaviourDescription::STANDARDSTRAINBASEDBEHAVIOUR) &&
+            (CalculiXInterface::hasFiniteStrainStrategy(mb)) &&
+            (getFiniteStrainStrategy(mb) ==
+             "MieheApelLambrechtLogarithmicStrainII")) {
+          isvs.push_back(
+              VariableDescription{"StrainStensor", "logarithmicStrain", 1, 0u});
+          isvs.push_back(VariableDescription{
+              "StressStensor", "dualOfTheLogarithmicStrain", 1, 0u});
+        }
+        write_variables_names(isvs, true, "SDV");
+        out << "\n";
         out << "*Depvar\n" << vsize << "\n";
       }
       if (!mps.first.empty()) {
@@ -1274,32 +1365,7 @@ namespace mfront {
       out << "*User Material, constants="
           << msize.getValueForModellingHypothesis(h);
       out << '\n';
-      if (!mps.first.empty()) {
-        int i = 1;
-        auto write = [&i, &out](const std::string& n) {
-          if (i % 9 == 0) {
-            out << "\n";
-            i = 1;
-          }
-          out << '<' << n << '>';
-          ++i;
-        };
-        for (auto pm = mps.first.begin(); pm != mps.first.end();) {
-          if (pm->arraySize == 1u) {
-            write(pm->getExternalName());
-          } else {
-            for (unsigned short a = 0; a != pm->arraySize;) {
-              write(pm->getExternalName() + "_" + std::to_string(a));
-              if (++a != pm->arraySize) {
-                out << ", ";
-              }
-            }
-          }
-          if (++pm != mps.first.end()) {
-            out << ", ";
-          }
-        }
-      }
+      write_variables_names(mps.first, false);
       out << "\n\n";
     } catch (std::exception& e) {
       if (getVerboseMode() > VERBOSE_QUIET) {
