@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   03/07/2022
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -20,7 +20,7 @@
 #include "TFEL/System/System.hxx"
 #include "TFEL/Material/ModellingHypothesis.hxx"
 #include "MFront/MFrontDebugMode.hxx"
-#include "MFront/DSLUtilities.hxx"
+#include "MFront/CodeGeneratorUtilities.hxx"
 #include "MFront/FileDescription.hxx"
 #include "MFront/SupportedTypes.hxx"
 #include "MFront/VariableDescription.hxx"
@@ -270,13 +270,16 @@ namespace mfront {
        << " * \\date   " << fd.date << '\n'
        << " */\n\n"
        << "#include <cmath>\n"
+       << "#include <locale>\n"
        << "#include <cstring>\n"
        << "#include <sstream>\n"
        << "#include \"TFEL/PhysicalConstants.hxx\"\n"
        << "#include \"TFEL/Config/TFELTypes.hxx\"\n"
-       << "#include \"TFEL/Math/Array/View.hxx\"\n";
+       << "#include \"TFEL/Math/Array/View.hxx\"\n"
+       << "#include\"TFEL/Math/General/DerivativeType.hxx\"\n";
     if (useQuantities(md)) {
-      os << "#include \"TFEL/Math/qt.hxx\"\n";
+      os << "#include\"TFEL/Math/qt.hxx\"\n"
+         << "#include\"TFEL/Math/Quantity/qtIO.hxx\"\n";
     }
     os << "#include \"TFEL/Material/BoundsCheck.hxx\"\n"
        << "#include \"MFront/CastemModel/" << header << "\"\n\n";
@@ -637,8 +640,22 @@ namespace mfront {
           continue;
         }
         const auto en = p.getExternalName();
+        if (en != p.name) {
+          os << (first ? "if" : "} else if")  //
+             << "(std::strcmp(\"" << en << "\", n) == 0){\n"
+             << "parameters." << p.name << " = " << p.type << "{v};\n"
+             << "return 1;\n";
+          first = false;
+        }
+        if ((!p.symbolic_form.empty()) && (p.symbolic_form != p.name)) {
+          os << (first ? "if" : "} else if")  //
+             << "(std::strcmp(\"" << p.symbolic_form << "\", n) == 0){\n"
+             << "parameters." << p.name << " = " << p.type << "{v};\n"
+             << "return 1;\n";
+          first = false;
+        }
         os << (first ? "if" : "} else if")  //
-           << "(std::strcmp(\"" << en << "\", n) == 0){\n"
+           << "(std::strcmp(\"" << p.name << "\", n) == 0){\n"
            << "parameters." << p.name << " = " << p.type << "{v};\n"
            << "return 1;\n";
         first = false;
@@ -695,8 +712,6 @@ namespace mfront {
     const auto name = md.library + md.className;
     const auto tfel_config = tfel::getTFELConfigExecutableName();
     auto& l = td.getLibrary(lib);
-    insert_if(l.cppflags,
-              "$(shell " + tfel_config + " --cppflags --compiler-flags)");
 #ifdef CASTEM_CPPFLAGS
     insert_if(l.cppflags, CASTEM_CPPFLAGS);
 #endif /* CASTEM_CPPFLAGS */
@@ -714,8 +729,6 @@ namespace mfront {
     }
 #endif /* CASTEM_ROOT */
 #endif /* LOCAL_CASTEM_HEADER_FILE */
-    insert_if(l.include_directories,
-              "$(shell " + tfel_config + " --include-path)");
     insert_if(l.sources, name + "-castem.cxx");
     td.headers.push_back("MFront/CastemModel/" + name + "-castem.hxx");
     insert_if(l.link_directories,
