@@ -4,7 +4,7 @@
  *
  * \author Thomas Helfer
  * \date   04 jun 2007
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -23,6 +23,7 @@
 #endif /* MFRONT_HAVE_MADNEX */
 
 #include "TFEL/Raise.hxx"
+#include "TFEL/Config/GetInstallPath.hxx"
 #include "TFEL/Glossary/Glossary.hxx"
 #include "TFEL/Math/IntegerEvaluator.hxx"
 #include "TFEL/UnicodeSupport/UnicodeSupport.hxx"
@@ -31,10 +32,10 @@
 
 #include "MFront/MFront.hxx"
 #include "MFront/PedanticMode.hxx"
+#include "MFront/MFrontWarningMode.hxx"
 #include "MFront/SupportedTypes.hxx"
 #include "MFront/DSLBase.hxx"
 #include "MFront/SearchPathsHandler.hxx"
-#include "MFront/DSLUtilities.hxx"
 #include "MFront/MFrontUtilities.hxx"
 #include "MFront/MFrontDebugMode.hxx"
 #include "MFront/MFrontLogStream.hxx"
@@ -314,6 +315,11 @@ namespace mfront {
 
   DSLBase::~DSLBase() = default;
 
+  bool DSLBase::readSafeOptionTypeIfPresent() {
+    return ::mfront::readSafeOptionTypeIfPresent(this->current,
+                                                 this->tokens.end());
+  }  // end of readSafeOptionTypeIfPresent
+
   void DSLBase::readNextBlock(CodeBlock& res1,
                               CodeBlock& res2,
                               const CodeBlockParserOptions& o1,
@@ -343,8 +349,8 @@ namespace mfront {
             r += std::string(d, ' ');
           }
         };
-    const auto& smn = options.smn;
-    const auto& mn = options.mn;
+    const auto& smn = options.static_member_names;
+    const auto& mn = options.member_names;
     const auto& delim1 = options.delim1;
     const auto& delim2 = options.delim2;
     const auto addThisPtr = options.qualifyMemberVariables;
@@ -924,14 +930,49 @@ namespace mfront {
     }
   }  // end of treatLink
 
-  void DSLBase::callMFront(const std::vector<std::string>& interfaces,
-                           const std::vector<std::string>& files) {
+  void DSLBase::treatTFELLibraries() {
+    const auto nlink = readStringOrArrayOfString("DSLBase::treatTFELLibraries");
+    this->readSpecifiedToken("DSLBase::treatTFELLibraries", ";");
+    //
+    const auto tfel_config = tfel::getTFELConfigExecutableName();
+    insert_if(this->link_directories,
+              "$(shell " + tfel_config + " --library-path)");
+    const auto lmap = std::map<std::string, std::string>{
+        {"Exception", "--exceptions"},
+        {"Glossary", "--glossary"},
+        {"Material", "--material"},
+        {"MathCubicSpline", "--math-cubic-spline"},
+        {"MathKriging", "--math-kriging"},
+        {"MathParser", "--math-parser"},
+        {"Math", "--math"},
+        {"NUMODIS", "--numodis"},
+        {"System", "--system"},
+        {"Tests", "--tests"},
+        {"UnicodeSupport", "--unicode-support"},
+        {"Utilities", "--utilities"},
+        {"Config", "--config"},
+        {"MFront", "--mfront"},
+        {"MTest", "--mtest"}};
+    for (const auto& l : nlink) {
+      if (!lmap.contains(l)) {
+        this->throwRuntimeError("DSLBase::treatTFELLibraries",
+                                "unknown TFEL library '" + l + "'");
+      }
+      insert_if(this->link_libraries, "$(shell " + tfel_config +
+                                          " --library-dependency " +
+                                          lmap.at(l) + ")");
+    }
+  }  // end of treatTFELLibraries
+
+  void DSLBase::callMFront(const std::vector<std::string>& files,
+                           const std::vector<std::string>& interfaces,
+                           const tfel::utilities::DataMap& dsl_options) {
     MFront m;
     for (const auto& i : interfaces) {
       m.setInterface(i);
     }
     for (const auto& f : files) {
-      mergeTargetsDescription(this->td, m.treatFile(f), false);
+      mergeTargetsDescription(this->td, m.treatFile(f, dsl_options), false);
     }
   }  // end of callMFront
 
@@ -952,7 +993,7 @@ namespace mfront {
     this->readSpecifiedToken("DSLBase::treatMfront", "}");
     this->readSpecifiedToken("DSLBase::treatMfront", ";");
     for (const auto& f : vfiles) {
-      this->addExternalMFrontFile(f, vinterfaces);
+      this->addExternalMFrontFile(f, vinterfaces, {});
     }
   }  // end of treatMfront
 
@@ -1048,7 +1089,7 @@ namespace mfront {
           ".hxx\"");
       this->addMaterialLaw(mname);
       this->atds.push_back(std::move(t));
-      this->addExternalMFrontFile(path, {"mfront"});
+      this->addExternalMFrontFile(path, {"mfront"}, {});
     } catch (std::exception& e) {
       this->throwRuntimeError(
           "DSLBase::handleMaterialPropertyDescription",
@@ -1072,9 +1113,10 @@ namespace mfront {
 
   void DSLBase::treatLonelySeparator() {
     if (getPedanticMode()) {
-      getLogStream() << this->fd.fileName << ":" << this->current->line << ":"
-                     << this->current->offset
-                     << ": warning: extra ‘;’ [-pedantic]\n";
+      auto msg = std::ostringstream{};
+      msg << this->fd.fileName << ":" << this->current->line << ":"
+          << this->current->offset << ": warning: extra ‘;’ [-pedantic]\n";
+      reportWarning(msg.str());
     }
   }  // end of treatLonelySperator
 
@@ -1267,8 +1309,8 @@ namespace mfront {
     ++(this->current);
     this->checkNotEndOfFile("DSLBase::treatDSL", "expected ';'");
     if (this->current->value == "{") {
-      const auto o = tfel::utilities::DataParsingOptions{};
-      tfel::utilities::Data::read(this->current, this->tokens.end(), o);
+      std::ignore =
+          read<tfel::utilities::DataMap>(this->current, this->tokens.end());
     }
     this->readSpecifiedToken("DSLBase::treatDSL", ";");
   }  // end of treatDSL
@@ -1335,6 +1377,9 @@ namespace mfront {
     for (auto& l : this->td.libraries) {
       l.ldflags.insert(l.ldflags.end(), this->ldflags.begin(),
                        this->ldflags.end());
+      l.sources.insert(l.sources.end(),
+                       this->additional_libraries_sources.begin(),
+                       this->additional_libraries_sources.end());
       l.link_libraries.insert(l.link_libraries.end(),
                               this->link_libraries.begin(),
                               this->link_libraries.end());
