@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   28/04/2022
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -18,7 +18,7 @@
 #include "TFEL/System/System.hxx"
 #include "TFEL/Material/ModellingHypothesis.hxx"
 #include "MFront/MFrontDebugMode.hxx"
-#include "MFront/DSLUtilities.hxx"
+#include "MFront/CodeGeneratorUtilities.hxx"
 #include "MFront/FileDescription.hxx"
 #include "MFront/SupportedTypes.hxx"
 #include "MFront/VariableDescription.hxx"
@@ -220,7 +220,8 @@ namespace mfront {
        << "#include <sstream>\n"
        << "#include \"TFEL/PhysicalConstants.hxx\"\n"
        << "#include \"TFEL/Config/TFELTypes.hxx\"\n"
-       << "#include \"TFEL/Math/Array/View.hxx\"\n";
+       << "#include \"TFEL/Math/Array/View.hxx\"\n"
+       << "#include\"TFEL/Math/General/DerivativeType.hxx\"\n";
     if (useQuantities(md)) {
       os << "#include \"TFEL/Math/qt.hxx\"\n";
     }
@@ -368,20 +369,22 @@ namespace mfront {
           writePhysicalBoundsChecks(os, v, v.name + "_1", "1u", false, false);
         }
       };
-      for (const auto& mv : f.usedVariables) {
-        const auto [n, vdepth] = md.decomposeVariableName(mv);
-        if (md.outputs.contains(n)) {
-          const auto& v = md.outputs.getVariable(n);
-          write_physical_bounds(v, v.name, vdepth);
+      if (!areRuntimeChecksDisabled(md)) {
+        for (const auto& mv : f.usedVariables) {
+          const auto [n, vdepth] = md.decomposeVariableName(mv);
+          if (md.outputs.contains(n)) {
+            const auto& v = md.outputs.getVariable(n);
+            write_physical_bounds(v, v.name, vdepth);
+          }
+          if (md.inputs.contains(n)) {
+            const auto& v = md.inputs.getVariable(n);
+            write_physical_bounds(v, v.name, vdepth);
+          }
         }
-        if (md.inputs.contains(n)) {
-          const auto& v = md.inputs.getVariable(n);
-          write_physical_bounds(v, v.name, vdepth);
+        for (const auto& p : md.parameters) {
+          write_physical_bounds(p, p.name, 0u);
         }
       }
-      for (const auto& p : md.parameters) {
-        write_physical_bounds(p, p.name, 0u);
-      }
       //
       auto write_bounds = [&os, &raise](const VariableDescription& v,
                                         const std::string& n,
@@ -398,20 +401,22 @@ namespace mfront {
           writeBoundsChecks(os, v, v.name + "_1", "1u", "policy", false, false);
         }
       };
-      for (const auto& mv : f.usedVariables) {
-        const auto [n, vdepth] = md.decomposeVariableName(mv);
-        if (md.outputs.contains(n)) {
-          const auto& v = md.outputs.getVariable(n);
-          write_bounds(v, v.name, vdepth);
+      if (!areRuntimeChecksDisabled(md)) {
+        for (const auto& mv : f.usedVariables) {
+          const auto [n, vdepth] = md.decomposeVariableName(mv);
+          if (md.outputs.contains(n)) {
+            const auto& v = md.outputs.getVariable(n);
+            write_bounds(v, v.name, vdepth);
+          }
+          if (md.inputs.contains(n)) {
+            const auto& v = md.inputs.getVariable(n);
+            write_bounds(v, v.name, vdepth);
+          }
         }
-        if (md.inputs.contains(n)) {
-          const auto& v = md.inputs.getVariable(n);
-          write_bounds(v, v.name, vdepth);
+        for (const auto& p : md.parameters) {
+          write_bounds(p, p.name, 0u);
         }
       }
-      for (const auto& p : md.parameters) {
-        write_bounds(p, p.name, 0u);
-      }
       //
       os << f.body << '\n';
       for (const auto& mv : f.modifiedVariables) {
@@ -532,10 +537,6 @@ namespace mfront {
     const auto name = md.library + md.className;
     const auto tfel_config = tfel::getTFELConfigExecutableName();
     auto& l = td.getLibrary(lib);
-    insert_if(l.cppflags,
-              "$(shell " + tfel_config + " --cppflags --compiler-flags)");
-    insert_if(l.include_directories,
-              "$(shell " + tfel_config + " --include-path)");
     insert_if(l.sources, name + "-generic.cxx");
     td.headers.push_back("MFront/GenericModel/" + name + "-generic.hxx");
     insert_if(l.link_directories,
