@@ -1,9 +1,10 @@
+
 /*!
  * \file   mfront/src/IsotropicMisesCreepCodeGenerator.cxx
  * \brief
  * \author Thomas Helfer
  * \date   04/08/2022
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -12,7 +13,7 @@
  */
 
 #include <ostream>
-#include "MFront/DSLUtilities.hxx"
+#include "MFront/CodeGeneratorUtilities.hxx"
 #include "MFront/MFrontDebugMode.hxx"
 #include "MFront/IsotropicMisesCreepCodeGenerator.hxx"
 
@@ -40,17 +41,20 @@ namespace mfront {
        << "using namespace tfel::material;\n"
        << "using std::vector;\n";
     writeMaterialLaws(os, this->bd.getMaterialLaws());
+    if (this->bd.hasCode(h, BehaviourData::BeforeFlowRule)) {
+      os << this->bd.getCode(h, BehaviourData::BeforeFlowRule);
+    }
     os << this->bd.getCode(h, BehaviourData::FlowRule) << "return true;\n}\n\n"
        << "bool NewtonIntegration(){\n"
        << "constexpr auto newton_epsilon = "
-          "100*std::numeric_limits<strain>::epsilon();\n"
+       << "100*std::numeric_limits<strain>::epsilon();\n"
        << "bool converged=false;\n"
        << "strain newton_f;\n"
        << "strain newton_df;\n"
-       << "auto newton_ddp = strain{}; // previous correction of the Newton "
-          "algorithm\n"
+       << "// previous correction of the Newton algorithm\n"
+       << "auto newton_ddp = strain{};\n"
        << "const auto mfront_internal_3_mu_theta = "
-          "3*(this->theta)*(this->mu);\n"
+       << "3 * (this->theta) * (this->mu);\n"
        << "unsigned int iter=0;\n";
     os << "while((converged==false)&&(iter<(this->iterMax))){\n"
        << "this->seq = "
@@ -134,7 +138,7 @@ namespace mfront {
        << "* \\brief Integrate behaviour law over the time step\n"
        << "*/\n"
        << "[[nodiscard]] IntegrationResult\n"
-       << "integrate(const SMFlag smflag,const SMType smt) override{\n"
+       << "integrate(const SMFlag smflag,const SMType smt) override final{\n"
        << "using namespace std;\n";
     if (this->bd.useQt()) {
       os << "if(smflag!=MechanicalBehaviour<" << btype
@@ -147,7 +151,19 @@ namespace mfront {
          << "throw(runtime_error(\"invalid tangent operator flag\"));\n"
          << "}\n";
     }
-    os << "if(!this->NewtonIntegration()){\n";
+    if (this->bd.hasCode(h, BehaviourData::ComputePredictor)) {
+      os << this->bd.getCode(h, BehaviourData::ComputePredictor) << '\n';
+    }
+    this->writeBehaviourIntegratorPreprocessingStep(os);
+    os << "this->seq_e = sigmaeq(this->se);\n"
+       << "if (this->seq_e > \n"
+       << "real(0.01) * (this->young) * "
+       << "std::numeric_limits<real>::epsilon()){\n"
+       << "this->n = 3*(this->se)/(2*this->seq_e);\n"
+       << "} else {\n"
+       << "this->n = StrainStensor(strain(0));\n"
+       << "}\n"
+       << "if(!this->NewtonIntegration()){\n";
     if (this->bd.useQt()) {
       os << "return MechanicalBehaviour<" << btype
          << ",hypothesis, NumericType,use_qt>::FAILURE;\n";
@@ -166,13 +182,8 @@ namespace mfront {
          << ",hypothesis, NumericType,false>::FAILURE;\n";
     }
     os << "}\n"
-       << "}\n"
-       << "this->deel = this->deto-(this->dp)*(this->n);\n"
-       << "this->updateStateVariables();\n"
-       << "this->sig  = "
-          "(this->lambda_tdt)*trace(this->eel)*StrainStensor::Id()+2*(this->mu_"
-          "tdt)*(this->eel);\n"
-       << "this->updateAuxiliaryStateVariables();\n";
+       << "}\n";
+    this->writeBehaviourIntegratorPostprocessingStep(os);
     if (!areRuntimeChecksDisabled(this->bd)) {
       for (const auto& v : d.getPersistentVariables()) {
         this->writePhysicalBoundsChecks(os, v, false);
@@ -223,21 +234,6 @@ namespace mfront {
        << "}\n\n";
   }
 
-  void IsotropicMisesCreepCodeGenerator::
-      writeBehaviourParserSpecificInitializeMethodPart(std::ostream& os,
-                                                       const Hypothesis) const {
-    this->checkBehaviourFile(os);
-    os << "this->se=2*(this->mu)*(tfel::math::deviator(this->eel+(this->theta)*"
-          "(this->deto)));\n"
-       << "this->seq_e = sigmaeq(this->se);\n"
-       << "if(this->seq_e> real(0.01)*(this->young) * std::numeric_limits<"
-          "real>::epsilon()){\n"
-       << "this->n = 3*(this->se)/(2*this->seq_e);\n"
-       << "} else {\n"
-       << "this->n = StrainStensor(strain(0));\n"
-       << "}\n";
-  }  // end of writeBehaviourParserSpecificInitializeMethodPart
-
   IsotropicMisesCreepCodeGenerator::~IsotropicMisesCreepCodeGenerator() =
       default;
 
