@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   15/03/2018
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -44,7 +44,7 @@ namespace mfront::bbrick {
     }
     const auto Rel = id.empty() ? "Rel" + fid : "Rel" + fid + "_" + id;
     const auto R = id.empty() ? "R" + fid : "R" + fid + "_" + id;
-    const auto dR = "d" + R + "_ddp" + fid;
+    const auto dR = "d" + R + "_dp" + fid;
     bd.reserveName(uh, Rel);
     bd.reserveName(uh, R);
     bd.reserveName(uh, dR);
@@ -113,7 +113,7 @@ namespace mfront::bbrick {
       const std::string& fid,
       const std::string& id) const {
     const auto R = id.empty() ? "R" + fid : "R" + fid + "_" + id;
-    const auto dR = "d" + R + "_ddp" + fid;
+    const auto dR = "d" + R + "_dp" + fid;
     const auto R0n = IsotropicHardeningRule::getVariableId("R0", fid, id);
     const auto Hn = IsotropicHardeningRule::getVariableId("H", fid, id);
     const auto pn = "p" + fid;
@@ -131,7 +131,7 @@ namespace mfront::bbrick {
       }
       c += "(this->" + Hn + ")*";
       c += "(this->" + pn + "+(this->theta)*(this->d" + pn + "));\n";
-      c += "const auto " + dR + " = (this->theta) * (this->" + Hn + ");\n";
+      c += "const auto " + dR + " = this->" + Hn + ";\n";
     } else {
       c += ";\n";
       c += "const auto " + dR + " = stress(0);\n";
