@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   10/01/2022
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -96,13 +96,17 @@ namespace mfront {
   }  // end of getAttributes
 
   void MaterialKnowledgeDescription::addExternalMFrontFile(
-      const std::string_view f, const std::vector<std::string>& interfaces) {
+      const std::string_view f,
+      const std::vector<std::string>& interfaces,
+      const tfel::utilities::DataMap& dsl_options) {
     const auto p = this->externalMFrontFiles.find(f);
     if (p == this->externalMFrontFiles.end()) {
-      this->externalMFrontFiles.insert({std::string{f}, interfaces});
+      this->externalMFrontFiles.insert(
+          {std::string{f}, {interfaces, dsl_options}});
     } else {
+#pragma message("treat DSL options")
       std::copy_if(interfaces.begin(), interfaces.end(),
-                   std::back_inserter(p->second),
+                   std::back_inserter(std::get<0>(p->second)),
                    [&interfaces](const std::string& i) {
                      return std::find(interfaces.begin(), interfaces.end(),
                                       i) == interfaces.end();
@@ -110,7 +114,9 @@ namespace mfront {
     }
   }  // end of addExternalMFrontFile
 
-  const std::map<std::string, std::vector<std::string>, std::less<>>&
+  const std::map<std::string,
+                 std::tuple<std::vector<std::string>, tfel::utilities::DataMap>,
+                 std::less<>>&
   MaterialKnowledgeDescription::getExternalMFrontFiles() const {
     return this->externalMFrontFiles;
   }  // end of getExternalMFrontFiles
