@@ -1,9 +1,10 @@
+
 /*!
  * \file   mfront/src/MultipleIsotropicMisesFlowsDSL.cxx
  * \brief
  * \author Thomas Helfer
  * \date   31 jan 2008
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -12,13 +13,12 @@
  */
 
 #include <string>
+#include <locale>
 #include <sstream>
 #include <stdexcept>
 #include "TFEL/Raise.hxx"
-#include "MFront/DSLUtilities.hxx"
 #include "MFront/MFrontDebugMode.hxx"
 #include "MFront/DSLFactory.hxx"
-#include "MFront/DSLUtilities.hxx"
 #include "MFront/MultipleIsotropicMisesFlowsCodeGenerator.hxx"
 #include "MFront/MultipleIsotropicMisesFlowsDSL.hxx"
 
@@ -45,10 +45,7 @@ namespace mfront {
     const auto h = ModellingHypothesis::UNDEFINEDHYPOTHESIS;
     this->mb.setDSLName("MultipleIsotropicMisesFlows");
     // Default state vars
-    this->mb.addStateVariable(
-        h, VariableDescription("StrainStensor", "εᵉˡ", "eel", 1u, 0u));
     this->mb.addStateVariable(h, VariableDescription("strain", "p", 1u, 0u));
-    this->mb.setGlossaryName(h, "eel", "ElasticStrain");
     this->mb.setGlossaryName(h, "p", "EquivalentStrain");
     // default local vars
     this->reserveName("mfront_internal_3_mu_theta");
@@ -140,9 +137,19 @@ namespace mfront {
     return "";
   }  // end of getCodeBlockTemplate
 
+  bool MultipleIsotropicMisesFlowsDSL::allowMultipleFlowRules() const {
+    return true;
+  }  // end of allowMultipleFlowRules
+
+  std::size_t MultipleIsotropicMisesFlowsDSL::getNumberOfFlowRules() const {
+    return this->flows.size();
+  }  // end of getNumberOfFlowRules
+
   void MultipleIsotropicMisesFlowsDSL::treatFlowRule() {
     const auto uh = ModellingHypothesis::UNDEFINEDHYPOTHESIS;
     FlowHandler flow;
+    auto opts = CodeBlockOptions{};
+    this->readCodeBlockOptions(opts, false);
     this->checkNotEndOfFile("MultipleIsotropicMisesFlowsDSL::treatFlowRule",
                             "Expected flow rule name.");
     if (this->current->value == "Plasticity") {
@@ -215,6 +222,7 @@ namespace mfront {
         "Expected the beginning of a block or a specific theta value.");
     if (this->current->value != "{") {
       std::istringstream converter(this->current->value);
+      converter.imbue(std::locale::classic());
       std::ostringstream otheta;
       std::ostringstream ose;
       std::ostringstream oseq_e;
@@ -236,12 +244,36 @@ namespace mfront {
       flow.hasSpecificTheta = false;
     }
     std::ostringstream cname;
-    cname << BehaviourData::FlowRule << flows.size() << '\n';
+    cname << BehaviourData::FlowRule << this->flows.size() << '\n';
     std::function<std::string(const Hypothesis, const std::string&, const bool)>
         m = [this](const Hypothesis h, const std::string& sv, const bool b) {
           return this->flowRuleVariableModifier(h, sv, b);
         };
-    this->treatCodeBlock(cname.str(), m, true, false);
+    const auto has_ihr = this->ihrs.contains(this->flows.size());
+    auto analyser = [this, &flow, has_ihr](CodeBlock& c, const Hypothesis,
+                                           const std::string& cv) {
+      if ((cv == "f") || (cv == "df_dseq")) {
+        c.block_variables.insert(cv);
+      }
+      if (cv == "df_dp") {
+        if (flow.flow == FlowHandler::CreepFlow) {
+          this->throwRuntimeError(
+              "MultipleIsotropicMisesFlowsDSL::treatFlowRule",
+              "the derivative 'df_dp' shall not be used in a flow rule "
+              "defining a creep flow.");
+        } else {
+          c.block_variables.insert(cv);
+        }
+      }
+      if (has_ihr) {
+        if ((cv == "R") || (cv == "dR_dp")) {
+          c.block_variables.insert(cv);
+        }
+      }
+    };
+    this->treatCodeBlock(opts, cname.str(), m, analyser, true);
+    this->checkFlowRule(cname.str(), this->flows.size(),
+                        flow.flow != FlowHandler::CreepFlow);
     flow.flowRule =
         this->mb.getCode(ModellingHypothesis::UNDEFINEDHYPOTHESIS, cname.str());
     this->flows.push_back(flow);
