@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \brief 10 juil. 2013
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -22,7 +22,7 @@
 #include "TFEL/System/System.hxx"
 #include "TFEL/Utilities/StringAlgorithms.hxx"
 
-#include "MFront/DSLUtilities.hxx"
+#include "MFront/CodeGeneratorUtilities.hxx"
 #include "MFront/InstallPath.hxx"
 #include "MFront/MFrontUtilities.hxx"
 #include "MFront/MFrontLogStream.hxx"
@@ -169,10 +169,8 @@ namespace mfront {
       tokens_iterator current,
       const tokens_iterator) {
     if (std::find(i.begin(), i.end(), this->getName()) != i.end()) {
-      tfel::raise(
-          "ZMATInterface::treatKeyword: "
-          "unsupported keyword '" +
-          key + "'");
+      tfel::raise("ZMATInterface::treatKeyword: unsupported keyword '" + key +
+                  "'");
     }
     return {false, current};
   }
@@ -214,8 +212,8 @@ namespace mfront {
   }  // edn of ZMATInterface::getModellingHypothesesToBeTreated
 
   std::pair<std::vector<BehaviourMaterialProperty>, SupportedTypes::TypeSize>
-  ZMATInterface::buildMaterialPropertiesList(
-      const BehaviourDescription& bd, const Hypothesis h) const {
+  ZMATInterface::buildMaterialPropertiesList(const BehaviourDescription& bd,
+                                             const Hypothesis h) const {
     const auto opts = BuildMaterialPropertiesListOptions{
         .useMaterialPropertiesToBuildStiffnessTensor = false,
         .useMaterialPropertiesToBuildThermalExpansionCoefficientTensor = false};
@@ -1765,15 +1763,11 @@ namespace mfront {
     const auto name = bd.getLibrary() + bd.getClassName();
     const auto tfel_config = tfel::getTFELConfigExecutableName();
     auto& l = d.getLibrary(lib);
-    insert_if(l.cppflags,
-              "$(shell " + tfel_config + " --cppflags --compiler-flags)");
     insert_if(l.cppflags, "$(shell " + tfel_config + " --zmat)");
 #pragma message("Linux specific")
     insert_if(l.cppflags, "-DLinux");
     insert_if(l.cppflags, "-DLinux_64");
     insert_if(l.cppflags, "-D_REENTRANT");
-    insert_if(l.include_directories,
-              "$(shell " + tfel_config + " --include-path)");
     insert_if(d.headers, "MFront/ZMAT/ZMAT" + name + ".hxx");
     insert_if(l.sources, "ZMAT" + name + ".cxx");
     insert_if(l.epts, bd.getClassName());
