@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   21 déc. 2015
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -122,11 +122,6 @@ namespace mtest {
         i = p->value;
       }
 #endif /* HAVE_ASTER */
-#ifdef HAVE_EUROPLEXUS
-      if ((p->value == "europlexus") || (p->value == "epx")) {
-        i = p->value;
-      }
-#endif /* HAVE_EUROPLEXUS */
 #ifdef HAVE_ABAQUS
       if ((p->value == "Abaqus") || (p->value == "abaqus") ||
           (p->value == "abaqus_standard") || (p->value == "abaqus_umat")) {
@@ -349,7 +344,7 @@ namespace mtest {
     } else {
       const int type = b->getInternalStateVariableType(ivs[0]);
       bool uniform = false;
-      if (type == 0) {
+      if (isScalarVariableType(type)) {
         uniform = p->value != "{";
       } else {
         tfel::raise_if(
@@ -401,11 +396,11 @@ namespace mtest {
     const auto p1 = std::find(esvs.begin(), esvs.end(), n);
     const auto p2 = std::find(esvs2.begin(), esvs2.end(), n);
     const auto b1 = p1 != esvs.end();
-    const auto b2 = p2 != esvs.end();
+    const auto b2 = p2 != esvs2.end();
     if (b1) {
       // full name of the external state variable
       const auto type = t.getBehaviour()->getExternalStateVariableType(n);
-      if (type == 0) {
+      if (isScalarVariableType(type)) {
         t.setExternalStateVariable(n, this->parseEvolution(t, evt, p), true);
       } else {
         const auto& components =
@@ -444,7 +439,7 @@ namespace mtest {
       SingleStructureScheme& t, tokens_iterator& p, const std::string& n) {
     const auto& b = *(t.getBehaviour());
     const auto type = b.getInternalStateVariableType(n);
-    if (type == 0) {
+    if (isScalarVariableType(type)) {
       t.setInternalStateVariableInitialValue(n, this->readDouble(t, p));
     } else {
       const auto s =
