@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \brief 03 mai 2011
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -134,7 +134,7 @@ namespace tfel::system {
         } else if (S_ISDIR(buf.st_mode)) {
           if ((strcmp(p->d_name, ".") != 0) && (strcmp(p->d_name, "..") != 0)) {
             std::map<std::string, std::vector<std::string>> r2;
-            recursiveFind(r2, re, name + '/' + p->d_name, depth + 1, mdepth);
+            recursiveFind(r2, re, name + '/' + p->d_name, b, depth + 1, mdepth);
             r.insert(r2.begin(), r2.end());
           }
         }
@@ -143,6 +143,6 @@ namespace tfel::system {
       }
     }
 #endif /* (defined _WIN32 || defined _WIN64) && (!defined __CYGWIN__) */
-  }  // end of recursiveFind
+  }    // end of recursiveFind
 
 }  // end of namespace tfel::system
