@@ -2,7 +2,7 @@
  * \file   tests/Math/stensor.cxx
  * \brief
  * \author Thomas Helfer
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -45,5 +45,11 @@ int main() {
   static_assert(s[0] == 1);
   static_assert(s[1] == 2);
   static_assert(s[2] == 3);
+  //
+  constexpr auto zero = stensor<2u, int>::zero();
+  static_assert(zero[0] == 0);
+  static_assert(zero[1] == 0);
+  static_assert(zero[2] == 0);
+  static_assert(zero[3] == 0);
   return EXIT_SUCCESS;
 }
