@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   12/05/2021
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -172,12 +172,14 @@ struct StensorViewTest final : public tfel::tests::TestCase {
                                   View<stensor<2u, double>, ipolicy>,  //
                                   ViewArrayPolicy<double, ipolicy>>>));
   }
-  void constexpr_test3() { using namespace tfel::math;
-    using time = qt<Time, double>;
+  void constexpr_test3() {
+    using namespace tfel::math;
+    using time = qt<unit::Time, double>;
     static_assert(std::same_as<scalar_view<float>, float&>);
     static_assert(std::same_as<scalar_view<const float>, const float&>);
-    static_assert(std::same_as<scalar_view<time>, qt_ref<Time, double>>);
-    static_assert(std::same_as<scalar_view<const time>, const qt_ref<Time, double>>);
+    static_assert(std::same_as<scalar_view<time>, qt_ref<unit::Time, double>>);
+    static_assert(std::same_as<scalar_view<const time>,
+                               const qt_ref<unit::Time, double>>);
   }
 
   //! \brief an helper method to check values
